==> nextcloud-app-bookmarks-1%3a2.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/nl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bladwijzers",
    "Add a Bookmark" : "Bladwijzer toevoegen",
    "Add folder" : "Map toevoegen",
    "Select" : "Selecteren",
    "Deselect" : "Deselecteren",
    "Details" : "Details",
    "Delete" : "Verwijderen",
    "Saved" : "Opgeslagen",
    "Date added" : "Datum toegevoegd",
    "Link" : "Link",
    "Tags" : "Tags",
    "Description" : "Beschrijving",
    "No bookmarks here." : "Hier zijn geen bladwijzers.",
    "Favorites" : "Favorieten",
    "Settings" : "Instellingen",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName} " : "Toevoegen aan {instanceName} ",
    "Recently added" : "Recent toegevoegd",
    "Most visited" : "Meest bezocht",
    "View mode" : "Weergavemodus",
    "List view" : "Lijstweergave",
    "RSS Feed" : "RSS Feed",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Verwijder alle bladwijzers permanent uit je account. Je kunt niet terug!",
    "Delete all bookmarks" : "Verwijder alle bladwijzers",
    "Open details" : "Details openen",
    "An error occurred while trying to save the bookmark." : "Er is een fout opgetreden bij je poging de bladwijzer op te slaan.",
    "Error" : "Fout",
    "Uncategorized" : "Niet gecategoriseerd",
    "Error parsing the import result" : "Fout bij interpreteren importresultaat",
    "Import completed successfully." : "Importeren succesvol afgerond.",
    "Do you really want to delete all your bookmarks?" : "Wil je echt al je bladwijzers verwijderen?",
    "Set tags" : "Instellen tags",
    "Not allowed to access folder to import into" : "Geen toegang tot map voor import",
    "Failed to import one bookmark, because: " : "Bladwijzer importeren mislukt, want:",
    "No file provided for import" : "Geen bestand aangeboden om te importeren",
    "Unsupported file type for import" : "Bestandstype wordt niet ondersteund voor importeren",
    "A Bookmark manager for Nextcloud" : "Een bladwijzerbeheerder voor Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Deze app laat je al je favoriete plekken op het web op één plaats opslaan en beheren, waarbij je ze ook nog eens kunt synchroniseren met al je apparaten en browsers.\nBekijk derde partij clients hier: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Voeg een bladwijzer toe",
    "This URL is already bookmarked! Overwrite?" : "Deze URL is al als bladwijzer aangemerkt! Overschrijven?",
    "The title of the page" : "De titel van de pagina",
    "The address of the page" : "Het adres van de pagina",
    "Description of the page" : "Beschrijving van de pagina",
    "Save" : "Opslaan",
    "Previews" : "Voorbeeldweergaven",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Om schermafdrukken van je bladwijzers te bekijken, kan de app een derde partij dienst gebruiken om die te genereren.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Je kunt je gratis aanmelden voor <a href=\"http://screeenly.com\">screeenly.com</a> of <a href=\"https://github.com/stefanzweifel/screeenly\">je eigen server instellen</a>.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "Bookmarks feed" : "Bladwijzerfeed"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3a2.1.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/nl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bladwijzers",
    "Not allowed to access folder to import into" : "Geen toegang tot map voor import",
    "Failed to import one bookmark, because: " : "Bladwijzer importeren mislukt, want:",
    "No file provided for import" : "Geen bestand aangeboden om te importeren",
    "Unsupported file type for import" : "Bestandstype wordt niet ondersteund voor importeren",
    "A Bookmark manager for Nextcloud" : "Een bladwijzerbeheerder voor Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\n\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Deze app laat je al je favoriete plekken op het web op één plaats opslaan en beheren, waarbij je ze ook nog eens kunt synchroniseren met al je apparaten en browsers.\n\nBekijk derde partij clients hier: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Details" : "Details",
    "Delete" : "Verwijderen",
    "Save" : "Opslaan",
    "Recently added" : "Recent toegevoegd",
    "Most visited" : "Meest bezocht",
    "RSS Feed" : "RSS Feed",
    "Delete all bookmarks" : "Verwijder alle bladwijzers",
    "Bookmarklet" : "Bookmarklet",
    "Do you really want to delete all your bookmarks?" : "Wil je echt al je bladwijzers verwijderen?",
    "Tags" : "Tags",
    "Select" : "Selecteren",
    "Previews" : "Voorbeeldweergaven",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "Add a bookmark" : "Voeg een bladwijzer toe",
    "This URL is already bookmarked! Overwrite?" : "Deze URL is al als bladwijzer aangemerkt! Overschrijven?",
    "Link" : "Link",
    "Bookmarks feed" : "Bladwijzerfeed"
},
"nplurals=2; plural=(n != 1);");
